@@ -23,6 +23,13 @@ else
     exit 1
 fi
 
+LOCAL_OVERRIDE=/etc/trebuchet/local_override
+
+if [ -f $LOCAL_OVERRIDE ]; then
+    source $LOCAL_OVERRIDE
+fi
+
+
 # clean up file
 cd {{ app_code }}
 
@@ -43,4 +50,4 @@ export LC_MEASUREMENT="${LOCALE}"
 export LC_IDENTIFICATION="${LOCALE}"
 export LC_ALL="${LOCALE}"
 
-{% block command_body %}{% endblock %}
\ No newline at end of file
+{% block command_body %}{% endblock %}
